special case of infer.dep.amount where there is only one station
infer.autocor.amount(
P.mat,
pr.state,
isPeriod,
nLag,
th,
parMargin,
typeMargin,
nChainFit,
isMAR,
isParallel
)list of estimates (e.g., M0, dfStudent)
precipitation matrix
probabilities of transitions for a Markov chain with lag p.
vector of logical n x 1 indicating the days concerned by a 3-month period
order of he Markov chain for the transitions between dry and wet states (=2 by default)
threshold above which we consider that a day is wet (e.g. 0.2 mm)
parameters of the margins 2 x 3
'EGPD' (Extended GPD) or 'mixExp' (Mixture of Exponentials). 'EGPD' by default
integer, length of the runs used during the fitting procedure. =100000 by default
logical value, do we apply a Autoregressive Multivariate Autoregressive model (order 1) =TRUE by default
logical: indicate computation in parallel or not (easier for debugging)
Guillaume Evin